{ Copyright (C) by Tobias Schwarz, 2003-2007
  Distributed under the GNU General Public License }

unit logfilesplitter;

interface

uses
  QForms, infofenster, wildmatch, QDialogs, QStdCtrls, QControls, QButtons,
  QExtCtrls, SysUtils, Classes, IniFiles, Split_Logfile, 
  YclZlib; {The YclZlib Unit is part of the Y core library, which is
    copyright by Peter J. Haas. Please visit http://delphi.pjh2.de/ for
    the most recent version of the library, supporting documentation and
    license terms.}

type
  TSplitterForm = class(TForm)
    OpenDialog: TOpenDialog;
    SplitBtn: TBitBtn;
    ExitBtn: TBitBtn;
    AboutBtn: TBitBtn;
    Panel1: TPanel;
    LogfileDialogBtn: TSpeedButton;
    Label1: TLabel;
    Label2: TLabel;
    LogfileEdit: TEdit;
    DomainEdit: TEdit;
    MixDomainsCheck: TCheckBox;
    Label7: TLabel;
    ProviderComboBox: TComboBox;
    Panel2: TPanel;
    Label3: TLabel;
    OutputFileDialogBtn: TSpeedButton;
    OutputFileEdit: TEdit;
    RemoveDomainBox: TCheckBox;
    Panel3: TPanel;
    AnalRecLabel: TLabel;
    FoundLabel: TLabel;
    CompressOutputBox: TCheckBox;
    TimeLabel: TLabel;
    Panel4: TPanel;
    RemoveDomainInRequest: TCheckBox;
    RemovedDomainsLbl: TLabel;
    procedure LogfileDialogBtnClick(Sender: TObject);
    procedure OutputFileDialogBtnClick(Sender: TObject);
    procedure ExitBtnClick(Sender: TObject);
    procedure AboutBtnClick(Sender: TObject);
    procedure SplitBtnClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    { Private-Deklarationen }
  public
    { Public-Deklarationen }
  end;

var
  SplitterForm: TSplitterForm;

implementation

{$R *.xfm}

procedure TSplitterForm.FormCreate(Sender: TObject);
var Inifile: TInifile;
    IniFileVersion: Integer;
begin
IniFile:=TIniFile.Create(GetEnvironmentVariable('HOME')+'/.logfilesplitter');
IniFileVersion:=IniFile.ReadInteger('ProgramProperty','ProgramVersion',150);
If IniFileVersion>=130 then begin
   Left:=IniFile.ReadInteger('WindowPos','Left',100);
   Top:=IniFile.ReadInteger('WindowPos','Top',100);
   LogfileEdit.Text:=IniFile.ReadString('LastSettings','Logfile',GetEnvironmentVariable('HOME'));
   ProviderComboBox.ItemIndex:=IniFile.ReadInteger('LastSettings','Provider',0);
   DomainEdit.Text:=IniFile.ReadString('LastSettings','Domain','');
   OutputFileEdit.Text:=IniFile.ReadString('LastSettings','OutputFile','');
   CompressOutputBox.Checked:=IniFile.ReadBool('LastSettings','CompressOutput',true);
   RemoveDomainBox.Checked:=IniFile.ReadBool('LastSettings','RemoveDomain',true);
   MixDomainsCheck.Checked:=IniFile.ReadBool('LastSettings','MixDomains',true);
end;
If IniFileVersion>=150 then begin
   RemoveDomainInRequest.Checked:=IniFile.ReadBool('LastSettings','RemoveDomainInRequest',false);
end;
IniFile.UpdateFile;
IniFile.Free;
end;

procedure TSplitterForm.LogfileDialogBtnClick(Sender: TObject);
begin
If DirectoryExists(LogfileEdit.Text) then OpenDialog.InitialDir:=LogfileEdit.Text;
If OpenDialog.Execute then LogfileEdit.Text:=OpenDialog.FileName;
end;

procedure TSplitterForm.OutputFileDialogBtnClick(Sender: TObject);
begin
If DirectoryExists(OutputFileEdit.Text) then OpenDialog.InitialDir:=OutputFileEdit.Text;
If OpenDialog.Execute then OutputFileEdit.Text:=OpenDialog.FileName;
end;

procedure TSplitterForm.ExitBtnClick(Sender: TObject);
begin
Close;
end;

procedure TSplitterForm.AboutBtnClick(Sender: TObject);
begin
Info:=TInfofenster.Create(self);
end;

procedure TSplitterForm.SplitBtnClick(Sender: TObject);
var SplitLog: TPreprocessLog;
begin
AnalRecLabel.Caption:='Analysed Records: 0';
FoundLabel.Caption:='Found Records: 0';
RemovedDomainsLbl.Caption:='Removed Domains: 0';
TimeLabel.Caption:='Time: 0 ms';
If FileExists(LogfileEdit.Text) then begin
   If CompressOutputBox.Checked and (ExtractFileExt(OutputFileEdit.Text)<>'.gz') then OutputFileEdit.Text:=OutputFileEdit.Text+'.gz';
   If FileExists(OutputFileEdit.Text) then
      If MessageDlg('File '+OutputFileEdit.Text+' already exists. Overwrite?',mtConfirmation,[mbYes, mbNo],0)=mrYes then begin
         DeleteFile(OutputFileEdit.Text);
      end else Exit;
   DomainEdit.Text:=Trim(DomainEdit.Text);
   SplitLog:=TPreprocessLog.Create;
   If ProviderComboBox.ItemIndex<>2 then begin
      SplitLog.SplitLog:=true;
      Case ProviderComboBox.ItemIndex of
         0: SplitLog.Provider:='1und1';
         1: SplitLog.Provider:='hosteurope';
      end;
      SplitLog.Mix:=MixDomainsCheck.Checked;
      SplitLog.Remove:=RemoveDomainBox.Checked;
   end;
   SplitLog.CompressFilteredLog:=CompressOutputBox.Checked;
   SplitLog.RemoveHost:=RemoveDomainInRequest.Checked;
   SplitLog.Hostname:=DomainEdit.Text;
   SplitLog.PreprocessLog(LogfileEdit.Text,OutputFileEdit.Text,DomainEdit.Text);
   TimeLabel.Caption:='Time: '+IntToStr(SplitLog.ProcessTime)+' ms';
   AnalRecLabel.Caption:='Analysed Records: '+IntToStr(SplitLog.Entries);
   FoundLabel.Caption:='Found Records: '+IntToStr(SplitLog.Found);
   RemovedDomainsLbl.Caption:='Removed Domains: '+IntToStr(SplitLog.HostnamesFound);
   SplitLog.Free;
end;
end;

procedure TSplitterForm.FormClose(Sender: TObject; var Action: TCloseAction);
var IniFile: TIniFile;
begin
IniFile:=TIniFile.Create(GetEnvironmentVariable('HOME')+'/.logfilesplitter');
IniFile.WriteInteger('ProgramProperty','IniFileVersion',150);
IniFile.WriteInteger('WindowPos','Left',Left);
IniFile.WriteInteger('WindowPos','Top',Top);
IniFile.WriteString('LastSettings','Logfile',LogfileEdit.Text);
IniFile.WriteInteger('LastSettings','Provider',ProviderComboBox.ItemIndex);
IniFile.WriteString('LastSettings','Domain',DomainEdit.Text);
IniFile.WriteString('LastSettings','OutputFile',OutputFileEdit.Text);
IniFile.WriteBool('LastSettings','CompressOutput',CompressOutputBox.Checked);
IniFile.WriteBool('LastSettings','RemoveDomain',RemoveDomainBox.Checked);
IniFile.WriteBool('LastSettings','MixDomains',MixDomainsCheck.Checked);
IniFile.WriteBool('LastSettings','RemoveDomainInRequest',RemoveDomainInRequest.Checked);
IniFile.UpdateFile;
IniFile.Free;
end;

end.
